@@ -1,5 +1,5 @@
 from samep.cogs.event import Event, event_table
-from samep.cogs.matching import Matching, matchi_table_, matching_table
+from samep.cogs.matching import Matching, matchi_table_, matching_table, baserole_table
 from samep.cogs.paneru import Paneru_, paneru_table
 from samep.cogs.reaction import Auto_Reaction, auto_reaction_table
 from samep.cogs.setting import Setting
@@ -14,4 +14,5 @@ def setup(bot):
     bot.add_table(matchi_table_)
     bot.add_table(matching_table)
     bot.add_table(paneru_table)
-    bot.add_table(auto_reaction_table)
\ No newline at end of file
+    bot.add_table(auto_reaction_table)
+    bot.add_table(baserole_table)
\ No newline at end of file
